/*
 * Copyright 2012 Martin Skurla
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.crazyjavahacking.astvisualizer.api;


import javax.tools.JavaFileObject;

import org.crazyjavahacking.astvisualizer.api.model.EdgeModel;
import org.crazyjavahacking.astvisualizer.api.model.NodeModel;
import org.jgrapht.DirectedGraph;


/**
 * Defines Abstract Syntax Tree parser. Every parser implementation is responsible for parsing using particular compiler
 * and adding additional information to tree.
 * <br/><br/>
 * Given implementations could be found using ServiceLoader.
 *
 * @author Martin
 */
public interface ASTParser {

    //-----------------------------------------------------------------------------------------------------------------
    // Public Methods.
    //-----------------------------------------------------------------------------------------------------------------
    /**
     * Parses given JavaFileObject into modified AST.
     *
     * @param sourceJavaFileObject source java file object
     *
     * @throws ASTParsingException if problem during parsing occurs
     *
     * @return modified AST
     */
    DirectedGraph<NodeModel, EdgeModel> parse(JavaFileObject sourceJavaFileObject);

    /**
     * Returns implementation compiler name.
     *
     * @return compiler name
     */
    String compilerName();

    /**
     * Returns implementation compiler version.
     *
     * @return compiler version
     */
    String compilerVersion();
}
