/*
 * Copyright 2012 Martin Skurla
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.crazyjavahacking.astvisualizer.impl.javac;


import com.sun.source.tree.ModifiersTree;


/**
 * Modifiers tree helper.
 *
 * @author Martin
 */
final class ModifiersTreeHelper {

    //-----------------------------------------------------------------------------------------------------------------
    // Constructors.
    //-----------------------------------------------------------------------------------------------------------------
    private ModifiersTreeHelper() {}


    //-----------------------------------------------------------------------------------------------------------------
    // Public Methods.
    //-----------------------------------------------------------------------------------------------------------------
    /**
     * Determines if given ModifiersTree has any flags or annotations.
     *
     * @param modifiersTree ModifiersTree
     *
     * @return <b>true</b>  if given ModifiersTree has any flags or annotations<br />
     *         <b>false</b> otherwise
     */
    public static boolean hasFlagsOrAnnotations(ModifiersTree modifiersTree) {
        int numberOfEdges = 0;

        numberOfEdges += modifiersTree.getFlags().size();
        numberOfEdges += modifiersTree.getAnnotations().size();

        return numberOfEdges != 0;
    }
}
