/*
 * Copyright 2012 Martin Skurla
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 */
package org.crazyjavahacking.astvisualizer.impl.javac.util;


import com.sun.source.tree.Tree;


/**
 * Compiler Tree API utility class.
 *
 * @author Martin
 */
public final class CompilerTreeAPIUtils {

    //-----------------------------------------------------------------------------------------------------------------
    // Constructors.
    //-----------------------------------------------------------------------------------------------------------------
    private CompilerTreeAPIUtils() {}


    //-----------------------------------------------------------------------------------------------------------------
    // Public Methods.
    //-----------------------------------------------------------------------------------------------------------------
    /**
     * Determines if given tree is Compilation Unit Tree.
     *
     * @param tree tree
     *
     * @return <b>true</b>  if given tree is Compilation Unit Tree<br />
     *         <b>false</b> otherwise
     */
    public static boolean isCompilationUnitTree(Tree tree) {
        return tree.getKind() == Tree.Kind.COMPILATION_UNIT;
    }

    /**
     * Determines if given tree is not Compilation Unit Tree.
     *
     * @param tree tree
     *
     * @return <b>true</b>  if given tree is not Compilation Unit Tree<br />
     *         <b>false</b> otherwise
     */
    public static boolean isNotCompilationUnitTree(Tree tree) {
        return !isCompilationUnitTree(tree);
    }

    /**
     * Determines if given tree is Modifiers Tree.
     *
     * @param tree tree
     *
     * @return <b>true</b>  if given tree is Modifiers Tree<br />
     *         <b>false</b> otherwise
     */
    public static boolean isModifiersTree(Tree tree) {
        return tree.getKind() == Tree.Kind.MODIFIERS;
    }

    /**
     * Determines if given tree is Block Tree.
     *
     * @param tree tree
     *
     * @return <b>true</b>  if given tree is Block Tree<br />
     *         <b>false</b> otherwise
     */
    public static boolean isBlockTree(Tree tree) {
        return tree.getKind() == Tree.Kind.BLOCK;
    }

    /**
     * Determines if given tree is Import Tree.
     *
     * @param tree tree
     *
     * @return <b>true</b>  if given tree is Import Tree<br />
     *         <b>false</b> otherwise
     */
    public static boolean isImportTree(Tree tree) {
        return tree.getKind() == Tree.Kind.IMPORT;
    }
}
